# -*- coding: utf-8 -*-

# Copyright (c) 2007 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Editor Typing configuration page.
"""

from PyQt4.QtCore import QVariant, pyqtSignature

from ConfigurationPageBase import ConfigurationPageBase
from Ui_EditorTypingPage import Ui_EditorTypingPage

import Preferences

class EditorTypingPage(ConfigurationPageBase, Ui_EditorTypingPage):
    """
    Class implementing the Editor Typing configuration page.
    """
    def __init__(self):
        """
        Constructor
        """
        ConfigurationPageBase.__init__(self)
        self.setupUi(self)
        self.setObjectName("EditorTypingPage")
        
        # set initial values
        self.pageIds = {}
        self.pageIds[' '] = self.stackedWidget.indexOf(self.emptyPage)
        self.pageIds['Python'] = self.stackedWidget.indexOf(self.pythonPage)
        languages = self.pageIds.keys()
        languages.sort()
        for language in languages:
            self.languageCombo.addItem(language, QVariant(self.pageIds[language]))
        
        # Python
        self.pythonInsertClosingBraceCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/InsertClosingBrace"))
        self.pythonSkipBraceCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/SkipBrace"))
        self.pythonIndentBraceCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/IndentBrace"))
        self.pythonInsertQuoteCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/InsertQuote"))
        self.pythonDedentElseCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/DedentElse"))
        self.pythonInsertImportCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/InsertImport"))
        self.pythonInsertSelfCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/InsertSelf"))
        self.pythonInsertBlankCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/InsertBlank"))
        self.pythonColonDetectionCheckBox.setChecked(\
            Preferences.getEditorTyping("Python/ColonDetection"))
        
        self.on_languageCombo_activated(' ')
        
    def save(self):
        """
        Public slot to save the Editor Typing configuration.
        """
        # Python
        Preferences.setEditorTyping("Python/InsertClosingBrace",
            int(self.pythonInsertClosingBraceCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/SkipBrace",
            int(self.pythonSkipBraceCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/IndentBrace",
            int(self.pythonIndentBraceCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/InsertQuote",
            int(self.pythonInsertQuoteCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/DedentElse",
            int(self.pythonDedentElseCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/InsertImport",
            int(self.pythonInsertImportCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/InsertSelf",
            int(self.pythonInsertSelfCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/InsertBlank",
            int(self.pythonInsertBlankCheckBox.isChecked()))
        Preferences.setEditorTyping("Python/ColonDetection",
            int(self.pythonColonDetectionCheckBox.isChecked()))
        
    @pyqtSignature("QString")
    def on_languageCombo_activated(self, language):
        """
        Slot documentation goes here.
        """
        try:
            index = self.pageIds[str(language)]
        except KeyEror:
            index = self.pageIds[' ']
        self.stackedWidget.setCurrentIndex(index)

def create(dlg):
    """
    Module function to create the configuration page.
    
    @param dlg reference to the configuration dialog
    """
    page = EditorTypingPage()
    return page
