# -*- coding: utf-8 -*-

# Copyright (c) 2006 - 2007 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Qt configuration page.
"""

from PyQt4.QtCore import QDir, pyqtSignature
from PyQt4.QtGui import QFileDialog

from KdeQt import KQFileDialog

from E4Gui.E4Completers import E4DirCompleter

from ConfigurationPageBase import ConfigurationPageBase
from Ui_QtPage import Ui_QtPage

import Preferences
import Utilities

class QtPage(ConfigurationPageBase, Ui_QtPage):
    """
    Class implementing the Qt configuration page.
    """
    def __init__(self):
        """
        Constructor
        """
        ConfigurationPageBase.__init__(self)
        self.setupUi(self)
        self.setObjectName("QtPage")
        
        self.qtCompleter = E4DirCompleter(self.qtEdit)
        self.qt4Completer = E4DirCompleter(self.qt4Edit)
        self.qt4TransCompleter = E4DirCompleter(self.qt4TransEdit)
        
        # set initial values
        self.disableQt3CheckBox.setChecked(Preferences.getQt("DisableQt3"))
        self.qtEdit.setText(Preferences.getQt("QtDir"))
        self.exportQtDirCheckBox.setChecked(Preferences.getQt("ExportQtDir"))
        self.qt4Edit.setText(Preferences.getQt("Qt4Dir"))
        self.exportQt4DirCheckBox.setChecked(Preferences.getQt("ExportQt4Dir"))
        self.qt4TransEdit.setText(Preferences.getQt("Qt4TranslationsDir"))
        
    def save(self):
        """
        Public slot to save the Qt configuration.
        """
        Preferences.setQt("DisableQt3", 
            int(self.disableQt3CheckBox.isChecked()))
        Preferences.setQt("QtDir", self.qtEdit.text())
        Preferences.setQt("ExportQtDir", 
            int(self.exportQtDirCheckBox.isChecked()))
        Preferences.setQt("Qt4Dir", self.qt4Edit.text())
        Preferences.setQt("ExportQt4Dir", 
            int(self.exportQt4DirCheckBox.isChecked()))
        Preferences.setQt("Qt4TranslationsDir", self.qt4TransEdit.text())
        
    @pyqtSignature("")
    def on_qtButton_clicked(self):
        """
        Private slot to handle the Qt3 directory selection.
        """
        dir = KQFileDialog.getExistingDirectory(\
            self,
            self.trUtf8("Select Qt3 Directory"),
            self.qtEdit.text(),
            QFileDialog.Options(QFileDialog.ShowDirsOnly))
            
        if not dir.isNull():
            self.qtEdit.setText(Utilities.toNativeSeparators(dir))
        
    def on_qtEdit_textChanged(self, dir):
        """
        Private slot to handle a change in the entered Qt3 directory.
        
        @param dir the entered string (QString)
        """
        self.exportQtDirCheckBox.setEnabled(not dir.isEmpty())
        
    @pyqtSignature("")
    def on_qt4Button_clicked(self):
        """
        Private slot to handle the Qt4 directory selection.
        """
        dir = KQFileDialog.getExistingDirectory(\
            self,
            self.trUtf8("Select Qt4 Directory"),
            self.qt4Edit.text(),
            QFileDialog.Options(QFileDialog.ShowDirsOnly))
            
        if not dir.isNull():
            self.qt4Edit.setText(Utilities.toNativeSeparators(dir))
        
    @pyqtSignature("")
    def on_qt4TransButton_clicked(self):
        """
        Private slot to handle the Qt4 translations directory selection.
        """
        dir = KQFileDialog.getExistingDirectory(\
            self,
            self.trUtf8("Select Qt4 Translations Directory"),
            self.qt4TransEdit.text(),
            QFileDialog.Options(QFileDialog.ShowDirsOnly))
            
        if not dir.isNull():
            self.qt4TransEdit.setText(Utilities.toNativeSeparators(dir))
        
    def on_qt4Edit_textChanged(self, dir):
        """
        Private slot to handle a change in the entered Qt directory.
        
        @param dir the entered string (QString)
        """
        self.exportQt4DirCheckBox.setEnabled(not dir.isEmpty())
    
def create(dlg):
    """
    Module function to create the configuration page.
    
    @param dlg reference to the configuration dialog
    """
    page = QtPage()
    return page
