# -*- coding: utf-8 -*-

# Copyright (c) 2007 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Package implementing lexers for the various supported programming languages.
"""

def getLexer(language, parent = None):
    """
    Module function to instantiate a lexer object for a given language.
    
    @param language language of the lexer (string)
    @param parent reference to the parent object (QObject)
    @return reference to the instanciated lexer object (QsciLexer)
    """
    try:
        if language == "Python":
            from LexerPython import LexerPython
            return LexerPython(parent)
        elif language == "C++":
            from LexerCPP import LexerCPP
            return LexerCPP(parent)
        elif language == "C#":
            from LexerCSharp import LexerCSharp
            return LexerCSharp(parent)
        elif language == "IDL":
            from LexerIDL import LexerIDL
            return LexerIDL(parent)
        elif language == "Java":
            from LexerJava import LexerJava
            return LexerJava(parent)
        elif language == "JavaScript":
            from LexerJavaScript import LexerJavaScript
            return LexerJavaScript(parent)
        elif language == "SQL":
            from LexerSQL import LexerSQL
            return LexerSQL(parent)
        elif language == "HTML":
            from LexerHTML import LexerHTML
            return LexerHTML(parent)
        elif language == "Perl":
            from LexerPerl import LexerPerl
            return LexerPerl(parent)
        elif language == "Bash":
            from LexerBash import LexerBash
            return LexerBash(parent)
        elif language == "Ruby":
            from LexerRuby import LexerRuby
            return LexerRuby(parent)
        elif language == "Lua":
            from LexerLua import LexerLua
            return LexerLua(parent)
        elif language == "CSS":
            from LexerCSS import LexerCSS
            return LexerCSS(parent)
        elif language == "TeX":
            from LexerTeX import LexerTeX
            return LexerTeX(parent)
        elif language == "Diff":
            from LexerDiff import LexerDiff
            return LexerDiff(parent)
        elif language == "Makefile":
            from LexerMakefile import LexerMakefile
            return LexerMakefile(parent)
        elif language == "Properties":
            from LexerProperties import LexerProperties
            return LexerProperties(parent)
        elif language == "Batch":
            from LexerBatch import LexerBatch
            return LexerBatch(parent)
        elif language == "D":
            from LexerD import LexerD
            return LexerD(parent)
        elif language == "Povray":
            from LexerPOV import LexerPOV
            return LexerPOV(parent)
        else:
            return None
    except ImportError:
        return None
